package nl.wimvanhaaren.securewicket.web;

import nl.wimvanhaaren.securewicket.web.security.SecureWicketAuthenticatedWebSession;
import nl.wimvanhaaren.wicket.WebResourceStreamLocator;

import org.apache.wicket.authroles.authentication.AbstractAuthenticatedWebSession;
import org.apache.wicket.authroles.authentication.AuthenticatedWebApplication;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.spring.injection.annot.SpringComponentInjector;
import org.apache.wicket.util.file.WebApplicationPath;

/**
 * Application object for your web application. If you want to run this
 * application without deploying, run the Start class.
 * 
 * @see nl.wimvanhaaren.securewicket.web.Start#main(String[])
 */
public class WicketApplication extends AuthenticatedWebApplication {

    private boolean isInitialized = false;

    @Override
    public void init() {
	if (!isInitialized) {
	    super.init();

	    // Use our custom resource finder
	    WebApplicationPath webContainerPathFinder = new WebApplicationPath(getServletContext());
	    WebResourceStreamLocator resourceStreamLocator = new WebResourceStreamLocator(webContainerPathFinder);
	    getResourceSettings().setResourceStreamLocator(resourceStreamLocator);

	    // Integrate Spring with Wicket
	    getComponentInstantiationListeners().add(new SpringComponentInjector(this));

	    isInitialized = true;
	}
    }

    @Override
    public Class<HomePage> getHomePage() {
	return HomePage.class;
    }

    @Override
    protected Class<? extends AbstractAuthenticatedWebSession> getWebSessionClass() {
	return SecureWicketAuthenticatedWebSession.class;
    }

    @Override
    protected Class<? extends WebPage> getSignInPageClass() {
	return LoginPage.class;
    }

}
