package nl.wimvanhaaren.securewicket.web.security;

import org.apache.log4j.Logger;
import org.apache.wicket.authroles.authentication.AuthenticatedWebSession;
import org.apache.wicket.authroles.authorization.strategies.role.Roles;
import org.apache.wicket.injection.Injector;
import org.apache.wicket.request.Request;
import org.apache.wicket.spring.injection.annot.SpringBean;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

public class SecureWicketAuthenticatedWebSession extends AuthenticatedWebSession {

    private static final long serialVersionUID = 3355101222374558750L;

    private static final Logger logger = Logger.getLogger(SecureWicketAuthenticatedWebSession.class);

    @SpringBean(name = "authenticationManager")
    private AuthenticationManager authenticationManager;

    public SecureWicketAuthenticatedWebSession(Request request) {
	super(request);
	injectDependencies();
	ensureDependenciesNotNull();
    }

    private void ensureDependenciesNotNull() {
	if (authenticationManager == null) {
	    throw new IllegalStateException("An authenticationManager is required.");
	}
    }

    private void injectDependencies() {
	// InjectorHolder.getInjector().inject(this);
	Injector.get().inject(this);
    }

    @Override
    public boolean authenticate(String username, String password) {
	boolean authenticated = false;
	try {
	    Authentication authentication = authenticationManager.authenticate(new UsernamePasswordAuthenticationToken(
		    username, password));
	    SecurityContextHolder.getContext().setAuthentication(authentication);
	    authenticated = authentication.isAuthenticated();
	} catch (AuthenticationException e) {
	    logger.warn(String.format("User '%s' failed to login. Reason: %s", username, e.getMessage()));
	    authenticated = false;
	}
	return authenticated;
    }

    @Override
    public Roles getRoles() {
	Roles roles = new Roles();
	getRolesIfSignedIn(roles);
	return roles;
    }

    private void getRolesIfSignedIn(Roles roles) {
	if (isSignedIn()) {
	    Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
	    addRolesFromAuthentication(roles, authentication);
	}
    }

    private void addRolesFromAuthentication(Roles roles, Authentication authentication) {
	for (GrantedAuthority authority : authentication.getAuthorities()) {
	    roles.add(authority.getAuthority());
	}
    }

}
