package nl.wimvanhaaren.wicket;

import java.util.Locale;

import org.apache.wicket.util.file.IResourceFinder;
import org.apache.wicket.util.resource.IResourceStream;
import org.apache.wicket.util.resource.locator.ResourceStreamLocator;
import org.apache.wicket.util.string.Strings;

public class WebResourceStreamLocator extends ResourceStreamLocator {

    /** If null, the application registered finder will be used */
    private IResourceFinder resourceFinder;

    public WebResourceStreamLocator() {
    }

    public WebResourceStreamLocator(final IResourceFinder resourceFinder) {
	this.resourceFinder = resourceFinder;
    }

    @Override
    public IResourceStream locate(Class<?> clazz, String path, String style, String variation, Locale locale,
	    String extension, boolean strict) {
	String simpleFileName = Strings.lastPathComponent(clazz.getName(), '.') + "." + extension;
	IResourceStream stream = locate(clazz, simpleFileName);
	if (stream != null) {
	    return stream;
	} else {
	    return super.locate(clazz, path, style, variation, locale, extension, strict);
	}
    }

    @Override
    protected IResourceStream locateByResourceFinder(Class<?> clazz, String path) {
	IResourceStream resourceStream = resourceFinder.find(clazz, path);
	if (resourceStream == null) {
	    // try using the class loader
	    resourceStream = locateByClassLoader(clazz, path);
	}
	return resourceStream;
    }

}
